==> fvwmconf_0.18-1.tar.gz: fvwmconf-0.18/lib/buttons.pl <==
require 'vector.pl';
{ # buttons context

    my ($junk,@w,$b,$bb,$j,@vars,$Which,$page);
 
    my $arrbg = 'CornflowerBlue';
    $b = $CONFIG{Decors}->{$DECOR}->{Buttons}->{ButtonStyles}->[0];
    my $ALLT = 0;

    my $rarr = "\@$bitmapdir/rdblarrow";
    my $larr = "\@$bitmapdir/ldblarrow";

    my @apad = (-ipadx=>'3',-ipady=>'3');

    for($j=0;$j<=9;$j++) {push @vars,"B$j";}
    push @vars, qw ( Init ReliefAUp ReliefADown  ReliefIA
		    ActiveUp ActiveDown Inactive );

#############################################################################
sub get_button_values_from_panel {
    foreach (@vars) {
#	print STDERR "getting $_: ";
	$b->{$_}->get_value_from_panel;
    }
}
###################################################################

sub put_button_values_on_panel {
    return unless Exists $SETBUTTONS;
    my $i=0;
    foreach (@vars){
	$b->{$_}->put_panel_ref($w[$i++]);
	$b->{$_}->put_value_on_panel();
    }
}

#############################################################################

sub set_current_button_style {
    my $num = shift;
    $num = 0 unless defined $num;
    $b = $CONFIG{Decors}->{$DECOR}->{Buttons}->{ButtonStyles}->[$num];
    $bb = $CONFIG{Decors}->{$DECOR}->{Buttons};
    $Which = $num;
    $page = $Which+1;
    put_button_values_on_panel();
}
#############################################################################
sub button_style_ref {
    return $b;
}


#############################################################################

sub set_buttons {
    
    $SETBUTTONS->destroy if Exists($SETBUTTONS);
    $SETBUTTONS = $MW->Toplevel(@topcon);
    my $w = $SETBUTTONS ;
    $w->title('Button Style');
    my $p = 18;

# This is fucking out of hand
    $b = $CONFIG{Decors}->{$DECOR}->{Buttons}->{ButtonStyles}->[0];
    $bb = $CONFIG{Decors}->{$DECOR}->{Buttons};
    $Which = 0;
    $page = 1;
    make_help_dismiss($w,'File:buttons');

  my $f = $w->Frame(@fracon,-relief=>'groove');
  $f->pack(-fill => 'both',-pady=>'6');
  my $apply = $f->Button(
			 @butcon,
			 -text => 'Apply',
			    -activebackground=> $applybg,


			 );
    $apply->configure(	-command => sub {
			     get_button_values_from_panel();
			     execute_decors(0);
			     set_unsaved();
			 }
		      );

   $apply->pack(-side => 'right', -fill => 'both');

    my $bt=$f->Button(@labcon,-text => 'Page ',
      -padx=>'3',-pady=>'3')->pack(-side=>'left',);
    bind_help($bt,"File:page");

    $f->Button(@butcon,-background=>$arrbg,-bitmap=>$larr,-command => 
           sub { $Which--; 
		 $Which = $bb->number_of_styles-1  if $Which < 0;
		 set_current_button_style($Which);
	     }
    )->pack(-side=>'left',@apad);

    $f->Label(@labcon,-textvariable =>\$page,
      -padx=>'4',-pady=>'4')->pack(-side=>'left',);

    $f->Button(@butcon,-background=>$arrbg,-bitmap=>$rarr,-command => 
           sub { $Which++; 
		 $Which = 0 if  $Which >= $bb->number_of_styles;
		 set_current_button_style($Which);
	     }
    )->pack(-side=>'left',@apad,);
    
    $f_a = $f->Frame(@fracon);
    $f_a->pack(-fill => 'both',-expand=>'1',-padx=>'60');
    $f_a->Label(@labcon, -text => " Decor: ")->pack(-side=>'left' ,);
    $f_a->Label(@labcon,-textvariable => \$DECOR)->pack(-side=>'left',);

    my $fn = $w->Frame(@fracon,-padx=>'4',-pady=>'4');
    $fn->pack(@EF);
    my $fna = $fn->Frame(@fracon);
    $fna->pack(-side=>'top',@EF);
    $bt = $fna->Button(@labcon,-text=>'Add Page' ,-padx=>'2',-pady=>'2')->pack(-side=>'left');
    bind_help($bt,"File:addpage");
    $fna->Button(@butcon,-bitmap=>$larr,-command => 
            sub {$bb->insert_style($Which);
		 set_current_button_style($Which);
		     }
        )->pack(-side=>'left',@apad);
    $fna->Button(@butcon,-bitmap=>$rarr,-command => 
            sub {$bb->insert_style($Which+1);
		 set_current_button_style($Which+1);
		     }
        )->pack(-side=>'left',@apad);

    $fna->Button(@butcon,-text=>'Vectors',-command => \&vector_tool)->pack(-side=>'right');
     $fnf = $fna->Frame(@fracon);
     $fnf->pack(-padx=>'20',-side=>'left');
     $fnf->Button(@butcon,-text=>'Delete Page',-activebackground=>'red',
        -command=> sub {
	      if ($bb->number_of_styles == 1) {beep();return;}
	      $bb->delete_style($Which);
	      $Which-- if $Which >= $bb->number_of_styles;
	      set_current_button_style($Which);
            })->pack(-side=>'right');



    my $fb = $w->Frame(@fracon);
    $fb->pack(-expand=>'y', -fill =>'both');
    for($j=0;$j<=9;$j++) {
	$w[$j] = $fb->Checkbutton(@radcon,
#-text=> "$j",
			     -variable => $b->{"B$j"}->get_panel_ref,
				  -onvalue => 'Y', -offvalue => 'N');
        $w[$j]->bind('<Button-2>' =>
		     sub {
			 my ($k,$t,$r);
			 if ($ALLT == 1) {
			     $t='Y';$ALLT=0;
			 }
			 else {
			     $t='N';$ALLT=1;
			 }
			 for($k=0;$k<=9;$k++) {
			     $r = $b->{"B$k"}->get_panel_ref;
			     $$r = $t;
			 }
		     }
        );
    }
    foreach (1,3,5,7,9) { $w[$_]->pack(-side=>'left');}
    foreach (2,4,6,8,0) { $w[$_]->pack(-side=>'right');}

    my $f1 = $w->Frame(@fracon);
    $f1->pack();
    ($junk,$w[10]) = radlablist($f1,pad('Initial',$p),$b->{Init}->get_panel_ref,
	'None ','None',
	'Default','Default',
        'Simple','Simple'
	  );

($junk,$w[11]) = radlablist($f1,pad('Active-Up Relief',$p),
	       $b->{ReliefAUp}->get_panel_ref,
	       'sunken  ', 'sunken',
	       'flat', 'flat',
	       'raised', 'raised'
	       );

($junk,$w[12]) = radlablist($f1,pad('Active-Down Relief',$p),
	       $b->{ReliefADown}->get_panel_ref,
	       'sunken  ', 'sunken',
	       'flat', 'flat',
	       'raised', 'raised'
	       );

($junk,$w[13]) = radlablist($f1,pad('Inactive Relief',$p),
	       $b->{ReliefIA}->get_panel_ref,
	       'sunken  ', 'sunken',
	       'flat', 'flat',
	       'raised', 'raised'
	       );

my $p1 = 14;
my $el = 32;
($junk,$w[14]) = labentlist($w,'L', pad('Active Up',$p1),'E',$el,
			$b->{ActiveUp});

($junk,$w[15]) = labentlist($w,'L', pad('Active Down ',$p1),'E',$el,
			$b->{ActiveDown});

($junk,$w[16]) = labentlist($w,'L', pad('Inactive ',$p1),'E',$el,
			$b->{Inactive});

put_button_values_on_panel();

}

}# end buttons context

1;

==> fvwmconf_0.19-3.tar.gz: fvwmconf-0.19/lib/buttons.pl <==
require 'vector.pl';
{ # buttons context

    my ($junk,@w,$b,$bb,$j,@vars,$Which,$page);
 
    my $arrbg = 'CornflowerBlue';
    $b = $CONFIG{Decors}->{$DECOR}->{Buttons}->{ButtonStyles}->[0];
    my $ALLT = 0;

    my $rarr = "\@$bitmapdir/rdblarrow";
    my $larr = "\@$bitmapdir/ldblarrow";

    my @apad = (-ipadx=>'3',-ipady=>'3');

    for($j=0;$j<=9;$j++) {push @vars,"B$j";}
    push @vars, qw ( Init ReliefAUp ReliefADown  ReliefIA
		    ActiveUp ActiveDown Inactive );

#############################################################################
sub get_button_values_from_panel {
    foreach (@vars) {
#	print STDERR "getting $_: ";
	$b->{$_}->get_value_from_panel;
    }
}
###################################################################

sub put_button_values_on_panel {
    return unless Exists $SETBUTTONS;
    my $i=0;
    foreach (@vars){
	$b->{$_}->put_panel_ref($w[$i++]);
	$b->{$_}->put_value_on_panel();
    }
}

#############################################################################

sub set_current_button_style {
    my $num = shift;
    $num = 0 unless defined $num;
    $b = $CONFIG{Decors}->{$DECOR}->{Buttons}->{ButtonStyles}->[$num];
    $bb = $CONFIG{Decors}->{$DECOR}->{Buttons};
    $Which = $num;
    $page = $Which+1;
    put_button_values_on_panel();
}
#############################################################################
sub button_style_ref {
    return $b;
}


#############################################################################

sub set_buttons {
    
    $SETBUTTONS->destroy if Exists($SETBUTTONS);
    $SETBUTTONS = $MW->Toplevel(@topcon);
    my $w = $SETBUTTONS ;
    $w->title('Button Style');
    my $p = 18;

# This is fucking out of hand
    $b = $CONFIG{Decors}->{$DECOR}->{Buttons}->{ButtonStyles}->[0];
    $bb = $CONFIG{Decors}->{$DECOR}->{Buttons};
    $Which = 0;
    $page = 1;
    make_help_dismiss($w,'File:buttons');

  my $f = $w->Frame(@fracon,-relief=>'groove');
  $f->pack(-fill => 'both',-pady=>'6');
  my $apply = $f->Button(
			 @butcon,
			 -text => 'Apply',
			    -activebackground=> $applybg,


			 );
    $apply->configure(	-command => sub {
			     get_button_values_from_panel();
			     execute_decors(0);
			     set_unsaved();
			 }
		      );

   $apply->pack(-side => 'right', -fill => 'both');

    my $bt=$f->Button(@labcon,-text => 'Page ',
      -padx=>'3',-pady=>'3')->pack(-side=>'left',);
    bind_help($bt,"File:page");

    $f->Button(@butcon,-background=>$arrbg,-bitmap=>$larr,-command => 
           sub { $Which--; 
		 $Which = $bb->number_of_styles-1  if $Which < 0;
		 set_current_button_style($Which);
	     }
    )->pack(-side=>'left',@apad);

    $f->Label(@labcon,-textvariable =>\$page,
      -padx=>'4',-pady=>'4')->pack(-side=>'left',);

    $f->Button(@butcon,-background=>$arrbg,-bitmap=>$rarr,-command => 
           sub { $Which++; 
		 $Which = 0 if  $Which >= $bb->number_of_styles;
		 set_current_button_style($Which);
	     }
    )->pack(-side=>'left',@apad,);
    
    $f_a = $f->Frame(@fracon);
    $f_a->pack(-fill => 'both',-expand=>'1',-padx=>'60');
    $f_a->Label(@labcon, -text => " Decor: ")->pack(-side=>'left' ,);
    $f_a->Label(@labcon,-textvariable => \$DECOR)->pack(-side=>'left',);

#    my $fn = $w->Frame(@fracon,-padx=>'4',-pady=>'4');
    my $fn = $w->Frame(@fracon);
    $fn->pack(@EF);
    my $fna = $fn->Frame(@fracon);
    $fna->pack(-side=>'top',@EF);
    $bt = $fna->Button(@labcon,-text=>'Add Page' ,-padx=>'2',-pady=>'2')->pack(-side=>'left');
    bind_help($bt,"File:addpage");
    $fna->Button(@butcon,-bitmap=>$larr,-command => 
            sub {$bb->insert_style($Which);
		 set_current_button_style($Which);
		     }
        )->pack(-side=>'left',@apad);
    $fna->Button(@butcon,-bitmap=>$rarr,-command => 
            sub {$bb->insert_style($Which+1);
		 set_current_button_style($Which+1);
		     }
        )->pack(-side=>'left',@apad);

    $fna->Button(@butcon,-text=>'Vectors',-command => \&vector_tool)->pack(-side=>'right');
     $fnf = $fna->Frame(@fracon);
     $fnf->pack(-padx=>'20',-side=>'left');
     $fnf->Button(@butcon,-text=>'Delete Page',-activebackground=>'red',
        -command=> sub {
	      if ($bb->number_of_styles == 1) {beep();return;}
	      $bb->delete_style($Which);
	      $Which-- if $Which >= $bb->number_of_styles;
	      set_current_button_style($Which);
            })->pack(-side=>'right');



    my $fb = $w->Frame(@fracon);
    $fb->pack(-expand=>'y', -fill =>'both');
    for($j=0;$j<=9;$j++) {
	$w[$j] = $fb->Checkbutton(@radcon,
#-text=> "$j",
			     -variable => $b->{"B$j"}->get_panel_ref,
				  -onvalue => 'Y', -offvalue => 'N');
        $w[$j]->bind('<Button-2>' =>
		     sub {
			 my ($k,$t,$r);
			 if ($ALLT == 1) {
			     $t='Y';$ALLT=0;
			 }
			 else {
			     $t='N';$ALLT=1;
			 }
			 for($k=0;$k<=9;$k++) {
			     $r = $b->{"B$k"}->get_panel_ref;
			     $$r = $t;
			 }
		     }
        );
    }
    foreach (1,3,5,7,9) { $w[$_]->pack(-side=>'left');}
    foreach (2,4,6,8,0) { $w[$_]->pack(-side=>'right');}

    my $f1 = $w->Frame(@fracon);
    $f1->pack();
    ($junk,$w[10]) = radlablist($f1,pad('Initial',$p),$b->{Init}->get_panel_ref,
	'None ','None',
	'Default','Default',
        'Simple','Simple'
	  );

($junk,$w[11]) = radlablist($f1,pad('Active-Up Relief',$p),
	       $b->{ReliefAUp}->get_panel_ref,
	       'sunken  ', 'sunken',
	       'flat', 'flat',
	       'raised', 'raised'
	       );

($junk,$w[12]) = radlablist($f1,pad('Active-Down Relief',$p),
	       $b->{ReliefADown}->get_panel_ref,
	       'sunken  ', 'sunken',
	       'flat', 'flat',
	       'raised', 'raised'
	       );

($junk,$w[13]) = radlablist($f1,pad('Inactive Relief',$p),
	       $b->{ReliefIA}->get_panel_ref,
	       'sunken  ', 'sunken',
	       'flat', 'flat',
	       'raised', 'raised'
	       );

my $p1 = 14;
my $el = 32;
($junk,$w[14]) = labentlist($w,'L', pad('Active Up',$p1),'E',$el,
			$b->{ActiveUp});

($junk,$w[15]) = labentlist($w,'L', pad('Active Down ',$p1),'E',$el,
			$b->{ActiveDown});

($junk,$w[16]) = labentlist($w,'L', pad('Inactive ',$p1),'E',$el,
			$b->{Inactive});

put_button_values_on_panel();

}

}# end buttons context

1;
